@@ -1,8 +1,8 @@
 
-#' Print a Diagnostics Report
+#' Print a diagnostics report
 #'
-#' Print a diagnostics report, summarizing the state of a project using `renv`.
-#' This report can occasionally be useful when diagnosing issues with `renv`.
+#' Print a diagnostics report, summarizing the state of a project using renv.
+#' This report can occasionally be useful when diagnosing issues with renv.
 #'
 #' @inheritParams renv-params
 #'
@@ -38,36 +38,36 @@ diagnostics <- function(project = NULL) {
   )
 
   fmt <- "Diagnostics Report [renv %s]"
-  title <- sprintf(fmt, renv_metadata_version())
+  title <- sprintf(fmt, renv_metadata_version_friendly())
   lines <- paste(rep.int("=", nchar(title)), collapse = "")
-  vwritef(c(title, lines, ""))
+  writef(c(title, lines, ""))
 
   for (reporter in reporters) {
     tryCatch(reporter(project), error = renv_error_handler)
-    vwritef()
+    writef()
   }
 
 }
 
 renv_diagnostics_session <- function(project) {
-  vwritef(header("Session Info"))
+  writef(header("Session Info"))
   renv_scope_options(width = 80)
   print(sessionInfo())
 }
 
 renv_diagnostics_project <- function(project) {
-  vwritef(header("Project"))
-  vwritef("Project path: %s", renv_path_pretty(project))
+  writef(header("Project"))
+  writef("Project path: %s", renv_path_pretty(project))
 }
 
 renv_diagnostics_status <- function(project) {
-  vwritef(header("Status"))
+  writef(header("Status"))
   status(project = project)
 }
 
 renv_diagnostics_packages <- function(project) {
 
-  vwritef(header("Packages"))
+  writef(header("Packages"))
 
   # collect state of lockfile, library, dependencies
   lockfile <- renv_diagnostics_packages_lockfile(project)
@@ -89,8 +89,7 @@ renv_diagnostics_packages <- function(project) {
   )
 
   # sort
-  renv_scope_locale(category = "LC_COLLATE", locale = "C")
-  all <- sort(unique(all))
+  all <- csort(unique(all))
 
   # check which packages are direct, indirect requirements
   deps <- rep.int(NA_character_, length(all))
@@ -127,8 +126,8 @@ renv_diagnostics_packages <- function(project) {
 
   # print library codes
   fmt <- "[%s]: %s"
-  vwritef()
-  vwritef(fmt, format(seq_along(levels(flibpaths))), format(levels(flibpaths)))
+  writef()
+  writef(fmt, format(seq_along(levels(flibpaths))), format(levels(flibpaths)))
 
 }
 
@@ -162,7 +161,7 @@ renv_diagnostics_packages_lockfile <- function(project) {
 
   lockpath <- renv_lockfile_path(project = project)
   if (!file.exists(lockpath)) {
-    vwritef("This project has not yet been snapshotted: 'renv.lock' does not exist.")
+    writef("This project has not yet been snapshotted: 'renv.lock' does not exist.")
     return(list())
   }
 
@@ -175,7 +174,7 @@ renv_diagnostics_packages_library <- function(project) {
   library <- renv_paths_library(project = project)
   if (!file.exists(library)) {
     fmt <- "The project library %s does not exist."
-    vwritef(fmt, renv_path_pretty(library))
+    writef(fmt, renv_path_pretty(library))
   }
 
   snapshot(project = project, lockfile = NULL, type = "all")
@@ -184,20 +183,21 @@ renv_diagnostics_packages_library <- function(project) {
 
 renv_diagnostics_packages_dependencies <- function(project) {
 
-  dependencies(project,
-               progress = FALSE,
-               errors = "reported",
-               dev = TRUE)
+  renv_dependencies_impl(
+    project,
+    errors = "reported",
+    dev = TRUE
+  )
 
 }
 
 renv_diagnostics_abi <- function(project) {
 
-  vwritef(header("ABI"))
+  writef(header("ABI"))
   tryCatch(
     renv_abi_check(),
     error = function(e) {
-      vwritef(conditionMessage(e))
+      writef(conditionMessage(e))
     }
   )
 
@@ -205,19 +205,20 @@ renv_diagnostics_abi <- function(project) {
 
 renv_diagnostics_profile <- function(project) {
 
-  vwritef(header("User Profile"))
+  writef(header("User Profile"))
 
   userprofile <- "~/.Rprofile"
   if (!file.exists(userprofile))
-    return(vwritef("[no user profile detected]"))
+    return(writef("[no user profile detected]"))
 
-  deps <- dependencies(userprofile,
-                       progress = FALSE,
-                       errors = "reported",
-                       dev = TRUE)
+  deps <- renv_dependencies_impl(
+    userprofile,
+    errors = "reported",
+    dev = TRUE
+  )
 
   if (empty(deps))
-    return(vwritef("[no R packages referenced in user profile"))
+    return(writef("[no R packages referenced in user profile"))
 
   renv_scope_options(width = 200)
   print(deps)
@@ -225,13 +226,13 @@ renv_diagnostics_profile <- function(project) {
 }
 
 renv_diagnostics_settings <- function(project) {
-  vwritef(header("Settings"))
+  writef(header("Settings"))
   str(renv_settings_get(project))
 }
 
 renv_diagnostics_options <- function(project) {
 
-  vwritef(header("Options"))
+  writef(header("Options"))
 
   keys <- c(
     "defaultPackages",
@@ -252,19 +253,20 @@ renv_diagnostics_options <- function(project) {
 
 renv_diagnostics_envvars <- function(project) {
 
-  vwritef(header("Environment Variables"))
+  writef(header("Environment Variables"))
 
   envvars <- convert(as.list(Sys.getenv()), "character")
 
   useful <- c(
     "R_LIBS_USER", "R_LIBS_SITE", "R_LIBS",
     "HOME", "LANG", "MAKE",
+    grep("_proxy", names(envvars), ignore.case = TRUE, value = TRUE),
     grep("^RENV_", names(envvars), value = TRUE)
   )
 
   matches <- envvars[useful]
   if (empty(matches))
-    return(vwritef("[no renv environment variables available]"))
+    return(writef("[no renv environment variables available]"))
 
   names(matches) <- useful
   matches[is.na(matches)] <- "<NA>"
@@ -273,23 +275,23 @@ renv_diagnostics_envvars <- function(project) {
   keys <- names(matches)
   vals <- matches
   formatted <- paste(format(keys), vals, sep = " = ")
-  vwritef(formatted)
+  writef(formatted)
 
 }
 
 renv_diagnostics_path <- function(project) {
-  vwritef(header("PATH"))
+  writef(header("PATH"))
   path <- strsplit(Sys.getenv("PATH"), .Platform$path.sep, fixed = TRUE)[[1]]
-  vwritef(paste("-", path))
+  writef(paste("-", path))
 }
 
 renv_diagnostics_cache <- function(project) {
 
-  vwritef(header("Cache"))
+  writef(header("Cache"))
 
   fmt <- "There are a total of %s installed in the renv cache."
   cachelist <- renv_cache_list()
-  vwritef(fmt, nplural("package", length(cachelist)))
-  vwritef("Cache path: %s", renv_path_pretty(renv_paths_cache()))
+  writef(fmt, nplural("package", length(cachelist)))
+  writef("Cache path: %s", renv_path_pretty(renv_paths_cache()))
 
 }
